package src.ItemStore;
import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;
import java.util.Vector;

/** @author Ben Leov
 * 	
 *  Simple class used to to save and load "Items" to and from file.
 *  Currently saves everything in clear text.
 * */
public class ItemStore {

	private Vector items;
	private File file;
	private boolean restoreFromFile;
	public static final String DELIM = ";";
	
	/** Stores items in this file. If restore is set to false file will be
	 *  deleted and recreated. */
	public ItemStore(File file,boolean restoreFromFile){
		this.file=file;
		this.restoreFromFile=restoreFromFile;
		try {
		if(this.restoreFromFile){
			
			if(!file.exists())
				file.createNewFile();
			
		this.restoreFromFile();
		
		}else {
			
			if(file.exists())
				file.delete();
			
			file.createNewFile();
			items=new Vector();
			
		}
		
		} catch (IOException e) {
			e.printStackTrace();
		}

	}
	
	/** Returns true if succesfull. Saves all items in Array under this id.
	 *  If an item is already at this id, the item will be overwritten.
	 *  */
	public boolean save(Item[] i){
		
			FileWriter fw = new FileWriter(file,true);
			
			for(int x = 0; x< i.length; x++){
				
				Item item = i[x];
				
				int index = item.getID();
				
				Item existing = this.getItem(index);
					
				if(!(existing == null)){ //Item doesnt exist already.
					items.remove(existing); 			
					}

					items.add(item);
				}
			
			
			this.saveToFile();

			
			//Remove file
			fw.close();
			return true;
	}
	
	/** Reads items from file */
	public Vector restoreFromFile(){
		
		FileReader fr = new FileReader(file,10);
		
		Vector items = new Vector();
		
		for(;;){
			
			String line = fr.readLine();
			
			if(line==null)
			break;

			Item toAdd = this.getItem(line);
			if(toAdd != null)
			items.add(toAdd);
			
		}
	 
		this.items=items;
		
		return items;
		
	}
	
	public void saveToFile(){
		
		
		file.delete();
		try {
			file.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		FileWriter fw = new FileWriter(file,true);
		
		Iterator i = items.iterator();
		
		while(i.hasNext()){
			
			Item item = (Item)i.next();
			fw.write(this.getString(item));
			
		}
	
		fw.close();
	}
	
		/** Loads item from memory. */
	public Item getItem(int id){
		 
		Iterator ite = items.iterator();
		Vector toReturn = new Vector();
		
		if(items.size() == 0)
		return null;
		
		while (ite.hasNext()){
			
			Item it = (Item)ite.next();
			
			if(it.getID() == id){
			return it;
		 
			}
		}
		return null;
	}
	
	private String getString(Item i){
		
		return i.getID() + DELIM + i.getName() + DELIM + i.getValue() + "\n";
	}
	
	private Item getItem(String line){
		
		StringTokenizer st = new StringTokenizer(line,DELIM);
		try{
		String id = st.nextToken();
		String name = st.nextToken();
		String val = st.nextToken();
		Item i = new Item(Integer.parseInt(id),name,val);
		return i;
		} catch (NoSuchElementException npe){
			
			return null;
		}
		
		
		
	}
	/** Resets the itemstore, removing file, and list in memory
	 *  Warning! This will remove ALL data in the item store. */
	public void reset(){
	

		if(file.exists())
			file.delete();
		
		try {
			file.createNewFile();
			
		} catch (IOException e) {
			
			e.printStackTrace();
			
		}
		
		items=new Vector();
		
	
	}
	
	
}  
