package src.limim08;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFormattedTextField;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JSeparator;

/** 
 * @author Ben Leov
 * 
 * The preference window is a pop up that allows the user to enter in Name, Password, Server, 
 *  and Port information. It gets the instance of the preferences class from Main.java, and updates
 *  as required if users input is valid. */

public class PreferenceWindow extends JFrame implements ActionListener {

	private static PreferenceWindow pc;
	private static Dimension TXT_BOX_SIZE = new Dimension(100,15);
	private JFormattedTextField name,server,port;
	private JPasswordField pass;

	public static PreferenceWindow getPreferenceWindow(){
		
		if(pc != null){
			pc.init();
		return pc;
		}
		else pc = new PreferenceWindow();
		return pc;
		
	}
	
	 	private PreferenceWindow(){
	 		
	 		super("Server preferences");
	 		
	 		this.getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.Y_AXIS));
	 		
	 		JPanel prefPanel = new JPanel();
	 		prefPanel.setLayout(new BoxLayout(prefPanel,BoxLayout.Y_AXIS));
	 		
	 		Preferences pr = Main.preferences;
	 		
	 		JLabel namel = new JLabel("Name:");
	 		JLabel passl = new JLabel("Password:");
	 		JLabel serverl = new JLabel("Server:");
	 		JLabel portl = new JLabel("Port:");
	 		
	 		 name = new JFormattedTextField(pr.getUsername());
	 		 pass = new JPasswordField(pr.getPassword());
	 		 server = new JFormattedTextField(pr.getServer());
	 		 port = new JFormattedTextField(String.valueOf(pr.getServerPort()));
	 		
		 	name.setPreferredSize(TXT_BOX_SIZE);
		 	pass.setPreferredSize(TXT_BOX_SIZE);
		 	server.setPreferredSize(TXT_BOX_SIZE);
		 	port.setPreferredSize(TXT_BOX_SIZE);
		 		

	 		JPanel nameP = new JPanel();
	 		nameP.add(namel); nameP.add(name);
	 		
	 		JPanel passP = new JPanel();
	 		passP.add(passl); passP.add(pass);
	 		
	 		JPanel servP = new JPanel();
	 		servP.add(serverl); servP.add(server);
	 		
	 		JPanel portP = new JPanel();
	 		portP.add(portl); portP.add(port);
	 		
	 		prefPanel.add(nameP); 
	 		prefPanel.add(new JSeparator());
	 		prefPanel.add(passP); 
	 		prefPanel.add(new JSeparator());
	 		prefPanel.add(servP); 
	 		prefPanel.add(new JSeparator());  
	 		prefPanel.add(portP); 
	 		prefPanel.add(new JSeparator());
	 		
	 		JPanel contPanel = new JPanel();
	 		
	 		JButton cancel = new JButton("Cancel");
	 		JButton save = new JButton("Save");
	 		JButton reset = new JButton("Reset");
	 		
	 		contPanel.add(cancel);
	 		contPanel.add(save);
	 		contPanel.add(reset);
	 		
	 		this.getContentPane().add(prefPanel);
	 		this.getContentPane().add(contPanel);
	 		
	 		cancel.addActionListener(this);
	 		save.addActionListener(this);
	 		reset.addActionListener(this);

	 		this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
	 		this.pack();
	 		this.setVisible(true);
	 		
	 	}
	 	
	 	public void init(){
	 		Preferences pr = Main.preferences;
	 		name.setText(pr.getUsername());
	 		pass.setText(pr.getPassword());
	 		server.setText(pr.getServer());
	 		port.setText(String.valueOf(pr.getServerPort()));
			pc.pack();
			pc.setVisible(true);
	 	}
	 	
	 	public void actionPerformed(ActionEvent e){
	 		
	 		if(e.getSource().getClass().equals(JButton.class)){
	 			
	 			JButton pressed = (JButton)e.getSource();

	 			
	 			if(pressed.getText().compareTo("Cancel")==0){
	 				
	 				this.dispose();
	 			
	 			}else if(pressed.getText().compareTo("Save")==0){
	 				
	 				Preferences pr = Main.preferences;
	 				
	 				String nam = name.getText();
	 				String pas = String.valueOf(pass.getPassword());
	 				String ser = server.getText();
	 				
	 				pr.setUsername(nam);
	 				pr.setPassword(pas);
	 				pr.setServer(ser);
	 				
	 				try{
	 					int portI = Integer.parseInt(port.getText());
	 				pr.setServerPort(portI);
	 				} catch (NumberFormatException nfe){ //Number cannot be parsed
	 					 port.setText(Integer.toString(pr.getServerPort()));
	 					 JOptionPane.showMessageDialog(null,"The server port entered is not a valid number."); 
	 					 return;
	 				}
	 				
	 				//if(ser.trim().compareTo("")==0 ){ //Check Server
	 				//	JOptionPane.showMessageDialog(null,"Server address cannot be blank.");
	 				///	return;
	 				//}	 		
	 				
	 				pr.save();
	 				this.dispose();
	 				
	 			} else if(pressed.getText().compareTo("Reset")==0) {
	 				
	 				int choice = JOptionPane.showConfirmDialog(null,"This will reset your preferences to the default values. Are you sure?","Preferences Reset", JOptionPane.YES_NO_OPTION); 
	 				
	 				if(choice == JOptionPane.YES_OPTION){
	 					name.setText(null);
	 					pass.setText(null);
	 			 		server.setText(Preferences.DEFAULT_SERVER);
	 			 		port.setText(String.valueOf(Preferences.DEFAULT_PORT));
	 				}
	 				
	 			} else { //Unknown button
	 				System.out.println("PreferenceWindow/actionPerformed() - Unknown button");
	 			}
	 				
	 	}  else{
	 		
	 	}//Not a jbutton or a text field.. (?)
	 }
}


