package src.limim08;

import java.io.File;
import java.util.Iterator;
import java.util.Vector;

import src.ItemStore.Item;
import src.ItemStore.ItemStore;

/** 
 *  @author Ben Leov
 *  
 * This class is responsible for saving and loading stored information for the user. It uses
 *  an ItemStore to store the various attributes. */

public class Preferences {

	private String username;
	private String password;
	private String server;
	private int serverPort;
	private static String fileName = "./prefs.txt";
	private static File saveFile = new File(fileName);
	
	public static final String DEFAULT_SERVER = "www.edronsoft.com";
	public static final int DEFAULT_PORT = 80;
	
	/** Default preferences */
	public Preferences(){	
		this.reset();
	}
	
	public Preferences(String username, String passwd, String server, int serverPort){
		
		this.username=username;
		this.password=passwd;
		this.server=server;
		this.serverPort=serverPort;
	}	
	/** Saves to file */
	public void save(){
		
		ItemStore itemStore = new ItemStore(saveFile,true);

		Item usr = new Item(0,"username",this.getUsername());
		Item pass = new Item(1,"password",this.getPassword());
		Item server = new Item (2,"server", this.getServer());
		Item serverPort = new Item(3,"serverPort", Integer.toString(this.getServerPort()));
		
		Item[] prefs = {usr,pass,server,serverPort};
		itemStore.save(prefs);

	}
	/** loads from file */
	public static Preferences load(){
			
		ItemStore itemStore = new ItemStore(saveFile,true);	 
		
		Vector prefs = itemStore.restoreFromFile();
		
		if(prefs.size() == 0) //No preferences
			return new Preferences();
			
		Iterator i = prefs.iterator();
		
		String usrS="",pasS="",serS="",porS="";
		int port = -1;
	
		while(i.hasNext()){
			
			Item item =(Item)i.next();
			
			if(item.getName().compareTo("username")==0){
				usrS=item.getValue();
			} else if (item.getName().compareTo("password")==0){
				pasS=item.getValue();
			}else if (item.getName().compareTo("server")==0){
				serS=item.getValue();
			}else if (item.getName().compareTo("serverPort")==0){
				try{
				porS=item.getValue();
				port = Integer.parseInt(porS);
			} catch(NumberFormatException nfe){
				
				System.out.println("Preferences - NFE");
			}
			
			
			} else{
				System.out.println("WARNING- Unknown type!");
		
				
			}
			
		}
	
		Preferences pr = new Preferences(usrS,pasS,serS,port);
		 return pr;

		 
			//System.out.println("Preferences/load() - aioobe - Load failed.");
			//itemStore.reset();
			//return new Preferences();	
		
	}
	/** Resets all preferences to default values. */
	
	public void reset(){
		 this.username = null;
		 this.password = null;
		 this.server = DEFAULT_SERVER;
		 this.serverPort= DEFAULT_PORT;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getServer() {
		return server;
	}

	public void setServer(String server) {
		this.server = server;
	}

	public int getServerPort() {
		return serverPort;
	}

	public void setServerPort(int serverPort) {
		this.serverPort = serverPort;
	}

	public String getUsername() {
		return username;
	}

	public void setUsername(String username) {
		this.username = username;
	}
	
	
}
